==> _private_core_network-1.2.69.tar.gz: lib/network_resources/repository/tracking_repo.dart <==
import '../resources.dart';

class TrackingRepo {
  TrackingRepo._();

  static TrackingRepo? _instance;

  factory TrackingRepo([AppApi? api]) {
    if (_instance == null) _instance = TrackingRepo._();
    _instance!._api = api ?? AppApiImp();
    return _instance!;
  }

  late AppApi _api;

  Future<List<TrackingInfoModel>> getTrackingInfosForMeeting(
      {required meetingId, required cardType}) async {
    Map<String, dynamic> params = {
      'meetingId': meetingId,
      'cardType': cardType
    };
    NetworkResponse response = await _api.getTrackingInfosForMeeting(params);
    return response.data ?? [];
  }

  Future<List<TrackingInfoModel>> addUserOrProToTrackingPeople(
      {required meetingId,
      allowedTimeBeforeTrack = 0,
      allowedDistanceBeforeTrack = 0,
      manualStatus = 0,
      proId,
      userId}) async {
    Map<String, dynamic> params = {
      'meetingId': meetingId,
      "allowedTimeBeforeTrack": allowedTimeBeforeTrack,
      "allowedDistanceBeforeTrack": allowedDistanceBeforeTrack,
      "manualStatus": manualStatus,
      "proId": proId,
      "userId": userId
    };
    NetworkResponse response = await _api.addUserOrProToTrackingPeople(params);
    return response.data ?? [];
  }

  Future<List<TrackingInfoModel>> updateTrackingInfosForMeeting({
    required meetingId,
    required cardType,
    allowedTimeBeforeTrack,
    allowedDistanceBeforeTrack,
    manualStatus,
  }) async {
    Map<String, dynamic> params = {
      'meetingId': meetingId,
      'cardType': cardType
    };
    if (allowedTimeBeforeTrack != null)
      params.addAll({'allowedTimeBeforeTrack': allowedTimeBeforeTrack});
    if (allowedDistanceBeforeTrack != null)
      params.addAll({'allowedDistanceBeforeTrack': allowedDistanceBeforeTrack});
    if (manualStatus != null) params.addAll({'manualStatus': manualStatus});
    NetworkResponse response = await _api.updateTrackingInfosForMeeting(params);
    return response.data ?? [];
  }
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/repository/tracking_repo.dart <==
import '../resources.dart';

class TrackingRepo {
  TrackingRepo._();

  static TrackingRepo? _instance;

  factory TrackingRepo([AppApi? api]) {
    _instance ??= TrackingRepo._();
    _instance!._api = api ?? AppApiImp();
    return _instance!;
  }

  late AppApi _api;

  Future<List<TrackingInfoModel>> getTrackingInfosForMeeting(
      {required meetingId, required cardType}) async {
    Map<String, dynamic> params = {
      'meetingId': meetingId,
      'cardType': cardType
    };
    NetworkResponse response = await _api.getTrackingInfosForMeeting(params);
    return response.data ?? [];
  }

  Future<List<TrackingInfoModel>> addUserOrProToTrackingPeople(
      {required meetingId,
      allowedTimeBeforeTrack = 0,
      allowedDistanceBeforeTrack = 0,
      manualStatus = 0,
      proId,
      userId}) async {
    Map<String, dynamic> params = {
      'meetingId': meetingId,
      "allowedTimeBeforeTrack": allowedTimeBeforeTrack,
      "allowedDistanceBeforeTrack": allowedDistanceBeforeTrack,
      "manualStatus": manualStatus,
      "proId": proId,
      "userId": userId
    };
    NetworkResponse response = await _api.addUserOrProToTrackingPeople(params);
    return response.data ?? [];
  }

  Future<List<TrackingInfoModel>> updateTrackingInfosForMeeting({
    required meetingId,
    required cardType,
    allowedTimeBeforeTrack,
    allowedDistanceBeforeTrack,
    manualStatus,
  }) async {
    Map<String, dynamic> params = {
      'meetingId': meetingId,
      'cardType': cardType
    };
    if (allowedTimeBeforeTrack != null) {
      params.addAll({'allowedTimeBeforeTrack': allowedTimeBeforeTrack});
    }
    if (allowedDistanceBeforeTrack != null) {
      params.addAll({'allowedDistanceBeforeTrack': allowedDistanceBeforeTrack});
    }
    if (manualStatus != null) params.addAll({'manualStatus': manualStatus});
    NetworkResponse response = await _api.updateTrackingInfosForMeeting(params);
    return response.data ?? [];
  }
}
